***************************************************************************************
* Welfare Assistance to the Poor 
* Data Analysis for Table 1, Table 2, and Table A1
*
* This .do file creates the analysis reported in TABLE 1, TABLE 2, and TABLE A1 in:
* "Assessing the Programmatic Equivalence Assumption In Question Wording Experiments: 
*   Understanding Why Americans like Assistance to the Poor more than Welfare"
* Public Opinion Quarterly
* Gregory Huber and Celia Paris
*
* This version: July 16, 2012
*
***************************************************************************************

clear all
clear matrix
set memory 100m
capture log close
set more off 

**************************
* Pilot: Mechanical Turk *
**************************

run WATP02_SUB_Clean_Datasets.do
clear

log using "output\WATP_Log02_Ttests_and_TableA1.txt", text replace

use "sourcedata\Clean_WATP_MT.dta"

* Getting N 
tabstat origspendq, by (asstpoorvswelf) stat(n) save

* Comparison of Interest (Asst to Poor and Welfare) *
preserve 
collapse (mean) origspendq (semean)  se1=origspendq, by(asstpoorvswelf) 
outsheet using output\Table1_MeanSupportSpendingMTurk.csv, replace comma
restore

ttest origspendq, by(asstpoorvswelf) unequal /* P-values for ttests reported in Table 1. */

tab origspendq asstpoorvswelf, col nofreq /* This set of tabbed responses appears in Table A1: Tabbed Responses to Original Question. */


*******************
* Study 1: YouGov *
*******************

clear 
use "sourcedata\Clean_WATP_YG.dta"

* Getting N 
tabstat origspendq, by (watptreat) stat(n) save

* Comparison of Interest (Asst to Poor and Welfare) *
preserve 
collapse (mean) origspendq (semean)  se1=origspendq, by(watptreat) 
outsheet using output\Table1_MeanSupportSpendingYouGov.csv, replace comma
restore

ttest origspendq, by(watptreat) unequal /* P-values for ttests reported in Table 1. */

tab origspendq watptreat, col nofreq /* This set of tabbed responses appears in Table A1: Tabbed Responses to Original Question. */

* Percent Saying Program Falls Into Category *
preserve 
collapse (mean) cash housing fstamps soupshelters childcare socsecur medicaid taxcred disab (semean)  se1=cash se2=housing se3=fstamps se4=soupshelters se5=childcare se6=socsecur se7=medicaid se8=taxcred se9=disab, by(watptreat) 
outsheet using output\Table2_PercentSayingProgramFallsIntoCategory.csv, replace comma
restore

ttest cash, by(watptreat) unequal  /* P-values for ttests reported in Table 2. */
ttest housing, by(watptreat) unequal
ttest fstamps, by(watptreat) unequal
ttest soupshelters, by(watptreat) unequal
ttest childcare, by(watptreat) unequal
ttest socsecur, by(watptreat) unequal
ttest medicaid, by(watptreat) unequal
ttest taxcred, by(watptreat) unequal
ttest disab, by(watptreat) unequal


*********************************
* GSS Data, for Tables 1 and A1 *
*********************************

clear
use "sourcedata\Clean_WATP_GSS.dta"

* Getting N 
tabstat support, by (watptreat) stat(n) save

* Comparison of Interest (Asst to Poor and Welfare) *
preserve 
collapse (mean) support (semean)  se1=support, by(watptreat) 
outsheet using output\Table1_MeanSupportSpendingGSS.csv, replace comma
restore

ttest support, by(watptreat) unequal

tab support watptreat, col nofreq

log close
