/* Welfare Aid to the Poor 
Cleaning/Recoding File (runs automatically in WATP02_Perform_Analysis.do)
last updated: 7/16/12 */

clear
clear matrix
capture log close
set more off 

*******************
* Loading MT Data *
*******************

use "sourcedata\MTurk_WATP.dta"

*************************
* MT Renaming Variables *
*************************

rename v1 id
rename v2 datesub
rename v3 status
rename v4 contactid
rename v9 longitude
rename v10 latitude
rename v11 country
rename v12 city
rename v13 region 
rename v14 postal
rename v15 consent
rename v16 respid
rename v30 treatgov1
rename v31 welf_poor
rename v40 openq
rename v44 openprograms1st
rename v52 openprograms2nd

* Demographics
rename v17 yob
gen yobfix=yob if yob > 1900
gen age=2011-yobfix
rename v18 state
rename v19 d_female
recode d_female (0=0)(1=0)(*=1), gen(miss_gender)
label define genlabel 1 "female" 0 "male"
label values d_female genlabel

* Race
rename v20 white
rename v21 black
rename v22 hispanic
rename v23 asian
rename v24 nativeamer
rename v25 mixed
rename v26 raceother1
rename v27 raceother2
recode white (1=0) (*=1), gen(d_nonwhite)
egen race = rowfirst(white black hispanic asian nativeamer mixed raceother1)
label define racelabel 1 "White" 2 "Black" 3 "Hispanic" 4 "Asian" 5 "Native American" 6 "Mixed" 7 "Other"
label values race racelabel

* Demographics 2
rename v28 educ
label define educlabel 1 "no HS diploma" 2 "HS grad" 3 "some college, no deg" 4 "2-yr college" 5 "4-yr college" 6 "post-grad deg"
label values educ educlabel

rename v29 income
recode income (.=98)
label define inclabel 1 "less than $10,000" 2 "$10,000 - $14,999" 3 "$15,000 - $19,999" 4 "$20,000 - $24,999" 5 "$25,000 - $29,999" ///
	6 "$30,000 - $39,999" 7  "$40,000 - $49,999" 8 "$50,000 - $59,999" 9 "$60,000 - $69,999" 10 "$70,000 - $79,999" ///
	11 "$80,000 - $99,999" 12 "$100,000 - $119,999" 13 "$120,000 - $149,999" 14 "$150,000 or more" 15 "prefer not to say" 98 "skipped"
label values income inclabel

* Interest, Ideology, Partisanship
rename v33 interest
rename v34 ideol /*scaled -2 (v cons) to 2 (v lib), with 8 for not sure*/
recode ideol (8=.), gen(ideology)
* so for ideology, "not sure" is coded as missing
rename v35 pid3
label define pid3label 1 "Democrat" 2 "Republican" 3 "Independent" 4 "Other"
label values pid3 pid3label
*"1=Dem,2=Rep,3=Indep,4=Oth"
rename v36 pidoth
rename v37 piddemstrength
rename v38 pidrepstrength
rename v39 pidindepclose

tab pid3, gen(d_pidcat_)
drop d_pidcat_4

* To verify all demographic variables have proper scales:
foreach var of varlist d_pidcat_* d_nonwhite d_female age educ ideology interest income {
 tab `var'
 }


************************************
* MT Recoding Treatment Categories *
************************************

* Marker for Receiving GSS Formulation of Question
encode treatgov1, gen(treatgov)
recode treatgov (1=1)(.=0), gen(tr_dummy_gov)

* Marker for Comparison of Interest (Between Welfare and Assistance to the Poor)
encode welf_poor, gen(tr_3cat_watp)
recode tr_3cat_watp (1=1)(2=2)(3=3)(.=0), gen(miss_tr_3cat_watp)
recode tr_3cat_watp (1=1) (2=2) (*=.), gen(asstpoorvswelf)
drop if asstpoorvswelf==.
label define watplabel 1 "AsstPoor" 2 "Welf" 
label values asstpoorvswelf watplabel

* Marker for Receiving Open-Ended Programs Question
encode openq, gen(open_6cat)
gen op_dummy_prog=(open_6cat==2) | (open_6cat==5)

* Text of Open-Ended Response
gen programs=openprograms1st+openprograms2nd

* Checking for Missing Treatment Assignment
tab miss_tr_3cat_watp
drop if miss_tr_3cat_watp==0 
tab miss_tr_3cat_watp


*********************************
* MT Original Spending Question *
*********************************

rename v41 origspendq1
*originally 0=too little, 1=right amount, 2=too much
recode origspendq1 (0=1) (1=0) (2=-1) (*=.), gen(origspendq)
* scale: -1=spending too much (should spend less), 0=right amount, 1=spending too little (should spend more)
recode origspendq (.=1)(*=0), gen(miss_orspq)

***********************************
* MT Subsetting to Relevant Cases *
***********************************

drop if tr_dummy_gov==1 
tab tr_dummy_gov
drop tr_dummy_gov

save "sourcedata\Clean_WATP_MT.dta", replace


***********************
* Loading YouGov Data *
***********************
clear
use sourcedata\YG_WATP.dta

************************
* Recoding YouGov Data *
************************

rename treat2 watptreat
recode huber_spendpgms_1 (1=1)(2=0)(*=.), gen(cash)
recode huber_spendpgms_2 (1=1)(2=0)(*=.), gen(housing)
recode huber_spendpgms_3 (1=1)(2=0)(*=.), gen(fstamps)
recode huber_spendpgms_4 (1=1)(2=0)(*=.), gen(soupshelters)
recode huber_spendpgms_5 (1=1)(2=0)(*=.), gen(childcare)
recode huber_spendpgms_6 (1=1)(2=0)(*=.), gen(socsecur)
recode huber_spendpgms_7 (1=1)(2=0)(*=.), gen(medicaid)
recode huber_spendpgms_8 (1=1)(2=0)(*=.), gen(taxcred)
recode huber_spendpgms_9 (1=1)(2=0)(*=.), gen(disab)

recode huber_spendpoor (1=1) (2=0) (3=-1) (8=.), gen(origspendq)
*originally 1=too little, 2=right amount, 3=too much, 8=skipped
*new scale: -1=spending too much (should spend less), 0=right amount, 1=spending too little (should spend more)

save "sourcedata\Clean_WATP_YG.dta", replace

*************************
* Loading GSS 2010 Data *
*************************
clear
use sourcedata\GSS_WATP.dta

* Recoding Variables
egen suppcheck=rowtotal(natfare natfarey), missing
recode natfare (1=1) (2=0) (3=-1), gen(welfsupp)
recode natfarey (1=1) (2=0) (3=-1), gen(poorsupp)
egen support=rowtotal(welfsupp poorsupp), missing

* Creating Treatment Indicator
gen watptreat= (welfsupp==-1) | (welfsupp==0) |(welfsupp==1)
replace watptreat=2 if poorsupp==-1 | poorsupp==0 | poorsupp==1
recode watptreat (0=.)

save "sourcedata\Clean_WATP_GSS.dta", replace
